@@ -1,6 +1,7 @@
 from __future__ import annotations
-from typing import List, Optional
-from pydantic import BaseModel
+import html
+from typing import Annotated, List, Optional
+from pydantic import BaseModel, validator
 
 from .ListingImageModel import ListingImage 
 from .ProductionPartnerModel import ProductionPartner
@@ -11,7 +12,6 @@ from .UserModel import User
 from .PriceModel import Price
 from .ProductModel import Product
 
-
 class Video(BaseModel):
     video_id: int
     height: int
@@ -70,7 +70,7 @@ class DraftListing(BaseModel):
     type: str = "physical"
     
 class Listing(BaseModel):
-    listing_id: int
+    listing_id: Annotated[int, "listing_id"]
     user_id: int
     shop_id: int
     title: str
@@ -123,6 +123,18 @@ class Listing(BaseModel):
     skus: List[str]
     translations: Optional[List[Translation]]
     inventory: Optional[Inventory]
+    videos: Optional[List[Video]]
     views: Optional[int]
+
+    @validator("title")
+    def title_validator(cls, value):
+        new_value = html.unescape(value)
+        return new_value
     
+    @validator("description")
+    def description_validator(cls, value):
+        new_value = html.unescape(value)
+        return new_value
+    
+
 Inventory.update_forward_refs()
