@@ -1,3 +1,4 @@
+from typing import Optional
 from pydantic import BaseModel
 from .PriceModel import Price
 
@@ -11,6 +12,6 @@ class ShippingProfileUpgrade(BaseModel):
     price: Price
     secondary_price: Price
     shipping_carrier_id: int
-    mail_class: str
+    mail_class: Optional[str]
     min_delivery_days: int
     max_delivery_days: int
\ No newline at end of file
