@@ -1,7 +1,5 @@
 from dataclasses import dataclass
-from typing import List, Optional
-from urllib.parse import urlencode
-
+from typing import List, Optional, Union
 from requests.models import RequestEncodingMixin
 from etsy_apiv3.utils import EtsySession, Response
 from etsy_apiv3.models import (
@@ -12,10 +10,13 @@ from etsy_apiv3.models import (
 )
 from async_oauthlib import OAuth2Session as AsyncOauth2Session
 
+from etsy_apiv3.utils.EtsyOauth2Session import EtsyOauth2Session
+
+
 @dataclass
 class ListingResource:
     
-    session: EtsySession
+    session: Union[EtsySession, EtsyOauth2Session]
     
     def get_listing(self, listing_id: int, includes: str = "") -> Listing:
         """
@@ -32,7 +33,7 @@ class ListingResource:
         json = self.session.request(endpoint, params={"includes":includes})
         return Listing(**json)
 
-    def find_all_active_listings(self, limit=25, offset=0, keywords="", sort_on="created", sort_order="desc", min_price=None, max_price=None, taxonomy_id=None, shop_location="United States"):
+    def find_all_active_listings(self, limit=25, offset=0, keywords="", sort_on="created", sort_order="desc", min_price=None, max_price=None, taxonomy_id=None, shop_location="United States", _as="pydantic"):
         """
         Find All Active Listings By Keywords, Min price, Max Price Or Shop Location
 
@@ -59,7 +60,7 @@ class ListingResource:
         }
         
         json = self.session.request(endpoint, params=params)
-
+        
         return Response[Listing](**json)
     
     def find_all_active_listings_by_shop(self, shop_id: int, limit: int = 25, sort_on: str = "created", sort_order: str = "desc", offset: int = 0, keywords: str = ""):
@@ -120,7 +121,7 @@ class ListingResource:
         response = self.session.request(endpoint, "PUT", json=data)
         return Inventory(**response)
 
-    def get_listings_by_listing_ids(self, listing_ids: List[int], includes: str = "", _as="pydantic"):
+    def get_listings_by_listing_ids(self, listing_ids: List[int], includes: Optional[str] = None, _as="pydantic"):
         params = {
             "listing_ids":",".join(list(map(str, listing_ids))),
             "includes":includes
@@ -254,14 +255,17 @@ class ListingResource:
     def upload_listing_image(self, shop_id: int, listing_id: int, image: bytes, listing_image_id: int, rank: int = 1, overwrite: bool = False, is_watermarked: bool = False, alt_text: str = "") -> ListingImage:
         endpoint = f"shops/{shop_id}/listings/{listing_id}/images"
         data = {
-            "image": image,
-            "listing_image_id": listing_image_id,
+            #"image": image,
+            #"listing_image_id": None,
             "rank": rank,
             "overwrite": overwrite,
             "is_watermarked": is_watermarked,
             "alt_text": alt_text
         }
-        response = self.session.request(endpoint, "POST", data=data)
+        print(type(image))
+        response = self.session.request(endpoint, "POST", data=data, files={"image": image})
+        
+        
         return ListingImage(**response)
     
     def upload_multiple_images_to_listing(self, shop_id: int, listing_id: int, images: List[bytes], overwrite: bool = False, is_watermarked: bool = False, alt_text: str = "") -> List[ListingImage]:
@@ -305,7 +309,7 @@ class ListingResource:
 
     def create_draft_listing(self, shop_id: int, listing: DraftListing) -> Listing:
         endpoint = f"shops/{shop_id}/listings"
-        response = self.session.request(endpoint, "POST", data=listing.dict())
+        response = self.session.request(endpoint, "POST", data=listing.dict(exclude_none=True))
         return Listing(**response)
     
     def get_buyer_taxonomy_nodes(self) -> Response[Taxonomy]:
