@@ -1,7 +1,8 @@
 from typing import Optional
-from etsy_apiv3.utils import EtsySession, Response
+from etsy_apiv3.utils import EtsySession, Response, EtsyOauth2Session
 from dataclasses import dataclass
 from etsy_apiv3.models import ReturnPolicy
+from typing import Union
 
 @dataclass
 class ShopPolicyResource:
@@ -9,7 +10,7 @@ class ShopPolicyResource:
     Shop Policy Resource Of Etsy Api V3.
 
     """
-    session: EtsySession
+    session: Union[EtsySession, EtsyOauth2Session]
     
     def get_shop_return_policies(self, shop_id: int) -> Response[ReturnPolicy]:
         endpoint = f"shops/{shop_id}/policies/return"
